# __version__ = "0.0.58" # 周期增加月份支持
# __version__ = "0.0.59" # 增加Indicator
# __version__ = "0.0.60" # 增加datatimetype
# __version__ = "0.0.61" # query_hisotry_n由decimal改为返回float
# __version__ = "0.0.62" # DataTimeType -> Timing
# __version__ = "0.0.63" # 增加很多constant。例如ExecuteStrategy, IndicatorColumn等标准字段
# __version__ = "0.0.64" # 增加INTERVAL2SUBSCRIBE_TYPE。更新ks_utility到版本0.0.32
__version__ = "0.0.65" # 增加SUBSCRIBE_TYPE2INTERVAL